Please see [https://docs.mlcommons.org/cm4mlops/scripts/Docker-automation/prune-docker](https://docs.mlcommons.org/cm4mlops/scripts/Docker-automation/prune-docker) for the documentation of this CM script.
